@@ -16,7 +16,8 @@
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
  */
 
-#include <config.h>
+#include "config.h"
+
 #include <glib/gi18n.h>
 #include <syslog.h>
 #include <pwd.h>
@@ -84,6 +85,11 @@ print_cant_auth_errbox (void)
  * @username: Name of user or NULL if we should ask
  * @display: Name of display to register with the authentication system
  * @local: boolean if local
+ * @allow_retry: boolean.  Not used by verify-crypt.  If this code 
+ *               allowed the user to retry, this boolean would specify 
+ *               whether to enable this feature.  We only want this 
+ *               feature to work for normal login, not for asking for 
+ *               root password to call the configurator.
  *
  * Provides a communication layer between the operating system's
  * authentication functions and the gdmgreeter. 
@@ -92,7 +98,11 @@ print_cant_auth_errbox (void)
  */
 
 gchar *
-gdm_verify_user (GdmDisplay *d, const char *username, const gchar *display, gboolean local) 
+gdm_verify_user (GdmDisplay *d,
+		 const char *username,
+		 const gchar *display,
+		 gboolean local,
+		 gboolean allow_retry)
 {
     gchar *login, *passwd, *ppasswd;
     struct passwd *pwent;
@@ -106,7 +116,7 @@ gdm_verify_user (GdmDisplay *d, const char *username, const gchar *display, gboo
     gint reEnter, ret;
 #endif
 
-    if (local)
+    if (local && d->timed_login_ok)
 	    gdm_slave_greeter_ctl_no_ret (GDM_STARTTIMER, "");
 
     if (username == NULL) {
