@@ -69,17 +69,20 @@ void
 greeter_item_ulist_check_show_userlist (void)
 {
 	/*
-	 * If there are no users, then hide the rectangle used to contain the
-	 * userlist.  This id allows a rectangle to be defined with alpha
-	 * behind the userlist that also goes away when the list is empty.
+ 	 * If there are no users, then hide the rectangle used to contain the
+	 * userlist.  The userlist-rect id allows a rectangle to be defined
+	 * with alpha behind the userlist that also goes away when the list is
+	 * empty.
 	 */
-	if (num_users == 0 && user_list != NULL) {
+	if (num_users == 0) {
 		GreeterItemInfo *urinfo = greeter_lookup_id ("userlist-rect");
-		GnomeCanvasItem *item;
 
-		gtk_widget_hide (user_list);
+		if (user_list != NULL)
+			gtk_widget_hide (user_list);
 
 		if (urinfo) {
+			GnomeCanvasItem *item;
+
 			if (urinfo->group_item != NULL)
 				item = GNOME_CANVAS_ITEM (urinfo->group_item);
 			else
@@ -104,12 +107,6 @@ greeter_item_ulist_unset_selected_user (void)
 	selected_user = NULL;
 }
 
-gchar *
-greeter_item_ulist_get_selected_user (void)
-{
-	return selected_user;
-}
-
 static void
 check_for_displays (void)
 {
