@@ -527,6 +527,67 @@ ve_config_destroy (VeConfig *config)
 	g_free (config);
 }
 
+static gchar*
+strescape_but_high (const gchar *source)
+{
+	const guchar *p;
+	gchar *dest;
+	gchar *q;
+
+	g_return_val_if_fail (source != NULL, NULL);
+
+	p = (guchar *) source;
+	/* Each source byte needs maximally four destination chars (\000) */
+	q = dest = g_malloc (strlen (source) * 4 + 1);
+
+	while (*p) {
+		switch (*p) {
+			case '\b':
+				*q++ = '\\';
+				*q++ = 'b';
+				break;
+			case '\f':
+				*q++ = '\\';
+				*q++ = 'f';
+				break;
+			case '\n':
+				*q++ = '\\';
+				*q++ = 'n';
+				break;
+			case '\r':
+				*q++ = '\\';
+				*q++ = 'r';
+				break;
+			case '\t':
+				*q++ = '\\';
+				*q++ = 't';
+				break;
+			case '\\':
+				*q++ = '\\';
+				*q++ = '\\';
+				break;
+			case '\"':
+				*q++ = '\\';
+				*q++ = '"';
+				break;
+			default:
+				if (*p < ' ') {
+					*q++ = '\\';
+					*q++ = '0' + (((*p) >> 6) & 07);
+					*q++ = '0' + (((*p) >> 3) & 07);
+					*q++ = '0' + ((*p) & 07);
+				} else {
+					*q++ = *p;
+				}
+				break;
+		}
+		p++;
+	}
+	*q = 0;
+	return dest;
+}
+
+
 static void
 save_section (VeSection *section, FILE *fp)
 {
@@ -536,8 +597,7 @@ save_section (VeSection *section, FILE *fp)
 		if (line->type == VE_LINE_TEXT) {
 			VE_IGNORE_EINTR (fprintf (fp, "%s\n", line->string));
 		} else if (line->type == VE_LINE_KEY) {
-			char *out = g_strescape (ve_sure_string (line->string),
-						 G_CSET_LATINC G_CSET_LATINS);
+			char *out = strescape_but_high (ve_sure_string (line->string));
 			VE_IGNORE_EINTR (fprintf (fp, "%s=%s\n",
 						  line->key,
 						  out));
